@@ -44,15 +44,11 @@ class ExtraTreesAlgorithm(SklearnTreesEnsembleClassifierAlgorithm):
             n_jobs=params.get("n_jobs", -1),
             random_state=params.get("seed", 1),
         )
-        if "max_steps" in params:
-            self.max_steps = params["max_steps"]
+        self.max_steps = self.params.get("max_steps", self.max_steps)
 
     def file_extension(self):
         return "extra_trees"
 
-    def get_metric_name(self):
-        return "logloss"
-
 
 class ExtraTreesRegressorAlgorithm(SklearnTreesEnsembleRegressorAlgorithm):
 
@@ -80,13 +76,11 @@ class ExtraTreesRegressorAlgorithm(SklearnTreesEnsembleRegressorAlgorithm):
             n_jobs=params.get("n_jobs", -1),
             random_state=params.get("seed", 1),
         )
+        self.max_steps = self.params.get("max_steps", self.max_steps)
 
     def file_extension(self):
         return "extra_trees"
 
-    def get_metric_name(self):
-        return "rmse"
-
 
 # For binary classification target should be 0, 1. There should be no NaNs in target.
 et_params = {
