@@ -20,6 +20,8 @@ from supervised.utils.metric import (
     xgboost_eval_metric_f1,
     xgboost_eval_metric_average_precision,
     xgboost_eval_metric_accuracy,
+    xgboost_eval_metric_mse,
+    xgboost_eval_metric_user_defined,
 )
 from supervised.utils.config import LOG_LEVEL
 
@@ -119,6 +121,10 @@ class XgbAlgorithm(BaseAlgorithm):
             self.custom_eval_metric = xgboost_eval_metric_average_precision
         elif self.params.get("eval_metric", "") == "accuracy":
             self.custom_eval_metric = xgboost_eval_metric_accuracy
+        elif self.params.get("eval_metric", "") == "mse":
+            self.custom_eval_metric = xgboost_eval_metric_mse
+        elif self.params.get("eval_metric", "") == "user_defined_metric":
+            self.custom_eval_metric = xgboost_eval_metric_user_defined
 
         self.best_ntree_limit = 0
         logger.debug("XgbLearner __init__")
@@ -161,13 +167,13 @@ class XgbAlgorithm(BaseAlgorithm):
         max_time=None,
     ):
         dtrain = xgb.DMatrix(
-            X.to_numpy() if isinstance(X, pd.DataFrame) else X,
+            X.values if isinstance(X, pd.DataFrame) else X,
             label=y,
             missing=np.NaN,
             weight=sample_weight,
         )
         dvalidation = xgb.DMatrix(
-            X_validation.to_numpy()
+            X_validation.values
             if isinstance(X_validation, pd.DataFrame)
             else X_validation,
             label=y_validation,
@@ -202,6 +208,9 @@ class XgbAlgorithm(BaseAlgorithm):
             # callbacks=[time_constraint] # callback slows down by factor ~8
         )
 
+        del dtrain
+        del dvalidation
+
         # dump_list = self.model.get_dump()
         # num_trees = len(dump_list)
         # print(self.model.best_ntree_limit, num_trees)
@@ -258,7 +267,7 @@ class XgbAlgorithm(BaseAlgorithm):
             raise XgbAlgorithmException("Xgboost model is None")
 
         dtrain = xgb.DMatrix(
-            X.to_numpy() if isinstance(X, pd.DataFrame) else X, missing=np.NaN
+            X.values if isinstance(X, pd.DataFrame) else X, missing=np.NaN
         )
         a = self.model.predict(dtrain, ntree_limit=self.best_ntree_limit)
         return a
