@@ -571,8 +571,6 @@ class BaseAutoML(BaseEstimator, ABC):
         if self._max_single_prediction_time is not None:
             self._one_sample = X.iloc[:1].copy(deep=True)
 
-        # self._drop_data_variables(X)
-
     def _handle_drastic_imbalance(self, X, y, sample_weight=None):
         if self._ml_task == REGRESSION:
             return
@@ -635,19 +633,6 @@ class BaseAutoML(BaseEstimator, ABC):
         with open(data_info_path, "w") as fout:
             fout.write(json.dumps(self._data_info, indent=4))
 
-    def _drop_data_variables(self, X):
-
-        X.drop(X.columns, axis=1, inplace=True)
-
-    def _load_data_variables(self, X_train):
-        if X_train.shape[1] == 0:
-            X = load_data(self._X_path)
-            for c in X.columns:
-                X_train.insert(loc=X_train.shape[1], column=c, value=X[c])
-
-        os.remove(self._X_path)
-        os.remove(self._y_path)
-
     def save_progress(self, step=None, generated_params=None):
         if step is not None and generated_params is not None:
             self._all_params[step] = generated_params
@@ -941,7 +926,6 @@ class BaseAutoML(BaseEstimator, ABC):
             self._apply_constraints_stack_models()
 
         try:
-
             self.load_progress()
             if self._fit_level == "finished":
                 print(
@@ -951,20 +935,14 @@ class BaseAutoML(BaseEstimator, ABC):
             self._check_can_load()
 
             self.verbose_print(f"AutoML directory: {self._results_path}")
-            if self._mode == "Optuna" and self._total_time_limit is not None:
-                ttl = int(
-                    self._total_time_limit
-                    + len(self._algorithms) * self._optuna_time_budget
-                )
+            if self._mode == "Optuna":
+                ttl = int(len(self._algorithms) * self._optuna_time_budget)
                 self.verbose_print("Expected computing time:")
                 self.verbose_print(
-                    f"Total training time: Optuna + ML training = {ttl} seconds"
+                    f"Time for tuning with Optuna: len(algorithms) * optuna_time_budget = {int(len(self._algorithms) * self._optuna_time_budget)} seconds"
                 )
                 self.verbose_print(
-                    f"Total Optuna time: len(algorithms) * optuna_time_budget = {int(len(self._algorithms) * self._optuna_time_budget)} seconds"
-                )
-                self.verbose_print(
-                    f"Total ML model training time: {int(self._total_time_limit)} seconds"
+                    f"There is no time limit for ML model training after Optuna tuning (total_time_limit parameter is ignored)."
                 )
 
             self.verbose_print(
@@ -985,7 +963,15 @@ class BaseAutoML(BaseEstimator, ABC):
                 EDA.compute(X, y, os.path.join(self._results_path, "EDA"))
 
             # Save data
-            self._save_data(X.copy(deep=False), y, sample_weight, cv)
+            if sample_weight is not None:
+                self._save_data(
+                    X.copy(deep=False),
+                    y.copy(deep=False),
+                    sample_weight.copy(deep=False),
+                    cv,
+                )
+            else:
+                self._save_data(X.copy(deep=False), y.copy(deep=False), None, cv)
 
             tuner = MljarTuner(
                 self._get_tuner_params(
@@ -1129,9 +1115,6 @@ class BaseAutoML(BaseEstimator, ABC):
 
         except Exception as e:
             raise e
-        # finally:
-        #    if self._X_path is not None:
-        #        self._load_data_variables(X)
 
         return self
 
@@ -1425,6 +1408,9 @@ class BaseAutoML(BaseEstimator, ABC):
     def _get_total_time_limit(self):
         """ Gets the current total_time_limit"""
         self._validate_total_time_limit()
+        if self._get_mode() == "Optuna":
+            return None  # there no training limit for model in the Optuna mode
+            # just train and be happy with super models :)
         return deepcopy(self.total_time_limit)
 
     def _get_model_time_limit(self):
@@ -1771,7 +1757,10 @@ class BaseAutoML(BaseEstimator, ABC):
 
     def _validate_total_time_limit(self):
         """ Validates total_time_limit parameter"""
-        check_greater_than_zero_integer(self.total_time_limit, "total_time_limit")
+        if self.total_time_limit is None:
+            return
+        if self.total_time_limit is not None:
+            check_greater_than_zero_integer(self.total_time_limit, "total_time_limit")
 
     def _validate_model_time_limit(self):
         """ Validates model_time_limit parameter"""
