@@ -28,6 +28,10 @@ class HillClimbing:
             "explain_level",
             "model_architecture_json",
             "n_jobs",
+            "metric",
+            "eval_metric",
+            "custom_eval_metric_name",
+            "eval_metric_name",
         ]:
             if k in keys:
                 keys.remove(k)
@@ -41,7 +45,10 @@ class HillClimbing:
         permuted_keys = np.random.permutation(keys)
         key_to_update = None
         values = None
+
         for key_to_update in permuted_keys:
+            if key_to_update not in model_params:
+                continue
             values = model_params[key_to_update]
             if len(values) > 1:
                 break
