@@ -83,7 +83,7 @@ def negative_accuracy(y_true, y_predicted, sample_weight=None):
         y_predicted = (y_predicted > 0.5).astype(int)
     else:
         y_predicted = np.argmax(y_predicted, axis=1)
-    
+
     val = accuracy_score(y_true, y_predicted, sample_weight=sample_weight)
 
     return -val
@@ -170,6 +170,15 @@ def xgboost_eval_metric_accuracy(preds, dtrain):
     return "accuracy", negative_accuracy(target, preds, weight)
 
 
+def xgboost_eval_metric_mse(preds, dtrain):
+    # Xgboost needs to minimize eval_metric
+    target = dtrain.get_label()
+    weight = dtrain.get_weight()
+    if len(weight) == 0:
+        weight = None
+    return "mse", mean_squared_error(target, preds, sample_weight=weight)
+
+
 def lightgbm_eval_metric_r2(preds, dtrain):
     target = dtrain.get_label()
     weight = dtrain.get_weight()
@@ -195,7 +204,7 @@ def lightgbm_eval_metric_f1(preds, dtrain):
         cols = len(unique_targets)
         rows = int(preds.shape[0] / len(unique_targets))
         preds = np.reshape(preds, (rows, cols), order="F")
-        
+
     return "f1", -negative_f1(target, preds, weight), True
 
 
@@ -215,7 +224,7 @@ def lightgbm_eval_metric_accuracy(preds, dtrain):
         cols = len(unique_targets)
         rows = int(preds.shape[0] / len(unique_targets))
         preds = np.reshape(preds, (rows, cols), order="F")
-        
+
     return "accuracy", -negative_accuracy(target, preds, weight), True
 
 
@@ -266,11 +275,78 @@ class CatBoostEvalMetricAveragePrecision(object):
 
         preds = np.array(approxes[0])
         target = np.array(target)
-        weight = None  # np.array(weight)
+        if weight is not None:
+            weight = np.array(weight)
 
         return -negative_average_precision(target, preds, weight), 0
 
 
+class CatBoostEvalMetricMSE(object):
+    def get_final_error(self, error, weight):
+        return error
+
+    def is_max_optimal(self):
+        return False
+
+    def evaluate(self, approxes, target, weight):
+        assert len(approxes) == 1
+        assert len(target) == len(approxes[0])
+
+        preds = np.array(approxes[0])
+        target = np.array(target)
+        if weight is not None:
+            weight = np.array(weight)
+
+        return mean_squared_error(target, preds, sample_weight=weight), 0
+
+
+class UserDefinedEvalMetric:
+    # should always minimize
+    eval_metric = mean_squared_error  # set the default
+
+    def set_metric(self, feval):
+        UserDefinedEvalMetric.eval_metric = feval
+
+    def __call__(self, y_true, y_predicted, sample_weight=None):
+        return UserDefinedEvalMetric.eval_metric(y_true, y_predicted, sample_weight)
+
+
+def xgboost_eval_metric_user_defined(preds, dtrain):
+    target = dtrain.get_label()
+    weight = dtrain.get_weight()
+    if len(weight) == 0:
+        weight = None
+    metric = UserDefinedEvalMetric()
+    return "user_defined_metric", metric(target, preds, sample_weight=weight)
+
+
+def lightgbm_eval_metric_user_defined(preds, dtrain):
+    target = dtrain.get_label()
+    weight = dtrain.get_weight()
+    metric = UserDefinedEvalMetric()
+    return "user_defined_metric", metric(target, preds, sample_weight=weight), False
+
+
+class CatBoostEvalMetricUserDefined(object):
+    def get_final_error(self, error, weight):
+        return error
+
+    def is_max_optimal(self):
+        return False
+
+    def evaluate(self, approxes, target, weight):
+        assert len(approxes) == 1
+        assert len(target) == len(approxes[0])
+
+        preds = np.array(approxes[0])
+        target = np.array(target)
+        if weight is not None:
+            weight = np.array(weight)
+
+        metric = UserDefinedEvalMetric()
+        return metric(target, preds, sample_weight=weight), 0
+
+
 class Metric(object):
     def __init__(self, params):
         if params is None:
@@ -293,6 +369,7 @@ class Metric(object):
             "f1",  # negative
             "average_precision",  # negative
             "accuracy",  # negative
+            "user_defined_metric",
         ]
         if self.name == "logloss":
             self.metric = logloss
@@ -320,6 +397,8 @@ class Metric(object):
             self.metric = negative_average_precision
         elif self.name == "accuracy":
             self.metric = negative_accuracy
+        elif self.name == "user_defined_metric":
+            self.metric = UserDefinedEvalMetric.eval_metric
         # elif self.name == "rmsle": # need to update target preprocessing
         #    self.metric = rmsle     # to assure that target is not negative ...
         else:
